@@ -12,7 +12,7 @@ test_that("Correct results for all options with a modifed tsAirgap dataset (addi
             expect_that( round(mean(na.seasplit( x, algorithm = "interpolation" )), digits = 4),  is_identical_to(276.6285) )
             expect_that( round(mean(na.seasplit( x, algorithm = "locf" )), digits = 4),  is_identical_to(274.8333) )
             expect_that( round(mean(na.seasplit( x, algorithm = "mean" )), digits = 4),  is_identical_to(263.9913) )
-            expect_that( round(mean(na.seasplit( x, algorithm = "kalman" )), digits = 4),  is_identical_to(278.9561) )
+            expect_that( round(mean(na.seasplit( x, algorithm = "kalman",model = "auto.arima" )), digits = 4),  is_identical_to(275.6724) )
             expect_that( round(mean(na.seasplit( x, algorithm = "ma" )), digits = 4),  is_identical_to(274.9965) )
           })
 
@@ -26,7 +26,7 @@ test_that("Correct results for all options with a modifed tsAirgap dataset (addi
             expect_that( round(mean(na.seasplit( x, algorithm = "interpolation" )), digits = 4),  is_identical_to(280.5) )
             expect_that( round(mean(na.seasplit( x, algorithm = "locf" )), digits = 4),  is_identical_to(278.375) )
             expect_that( round(mean(na.seasplit( x, algorithm = "mean" )), digits = 4),  is_identical_to(283.4194) )
-            expect_that( round(mean(na.seasplit( x, algorithm = "kalman" )), digits = 4),  is_identical_to(280.6465) )
+            expect_that( round(mean(na.seasplit( x, algorithm = "kalman", model = "auto.arima"  )), digits = 4),  is_identical_to(278.5223) )
             expect_that( round(mean(na.seasplit( x, algorithm = "ma" )), digits = 4),  is_identical_to(281.0672) )
           })
 
@@ -40,7 +40,7 @@ test_that("Correct results for all options with the tsAirgap dataset",
             expect_that( round(mean(na.seasplit( x, algorithm = "interpolation" )), digits = 4),  is_identical_to(280.3194) )
             expect_that( round(mean(na.seasplit( x, algorithm = "locf" )), digits = 4),  is_identical_to(278.1944) )
             expect_that( round(mean(na.seasplit( x, algorithm = "mean" )), digits = 4),  is_identical_to(279.2833) )
-            expect_that( round(mean(na.seasplit( x, algorithm = "kalman" )), digits = 4),  is_identical_to(280.4408) )
+            expect_that( round(mean(na.seasplit( x, algorithm = "kalman", model = "auto.arima"  )), digits = 4),  is_identical_to(279.1549) )
             expect_that( round(mean(na.seasplit( x, algorithm = "ma" )), digits = 4),  is_identical_to(280.3135) )
           })
 
